@@ -1,14 +1,6 @@
 #' @export
 universals::nterms
 
-#' @inherit universals::nterms
-#' @export
-nterms.mcmc <- function(x, ...) ncol(x)
-
-#' @inherit universals::nterms
-#' @export
-nterms.mcmc.list <- function(x, ...) nterms(x[[1]])
-
 #' @inherit universals::nterms
 #' @export
 nterms.mcmcarray <- function(x, ...) as.integer(prod(dim(x)[-(1:2)]))
