@@ -1,10 +1,8 @@
-context("combine_dimensions")
-
 test_that("combine_dimensions.mcmcarray", {
   expect_identical(pdims(combine_dimensions(mcmcr_example$beta)), c(2L))
   expect_identical(pdims(combine_dimensions(mcmcr_example$beta, along = 1L)), c(2L))
-  expect_error(combine_dimensions(mcmcr_example$beta, along = 0L), "along must be NULL OR the values in along must lie between 1 and 2")
-  expect_error(combine_dimensions(mcmcr_example$beta, along = 3L), "along must be NULL OR the values in along must lie between 1 and 2")
+  expect_error(combine_dimensions(mcmcr_example$beta, along = 0L), "^`along` must be between 1 and 2, not 0[.]$", class = "chk_error")
+  expect_error(combine_dimensions(mcmcr_example$beta, along = 3L), "^`along` must be between 1 and 2, not 3[.]$", class = "chk_error")
   expect_identical(pdims(combine_dimensions(mcmcr_example$alpha)), 1L)
   expect_identical(pdims(combine_dimensions(mcmcr_example$sigma)), 1L)
   expect_identical(pdims(combine_dimensions(mcmcr_example2$sigma, along = 1L)), c(1L, 1L))
@@ -13,7 +11,11 @@ test_that("combine_dimensions.mcmcarray", {
 
 test_that("combine_dimensions.mcmcr", {
   expect_equal(combine_dimensions(bind_dimensions_n(mcmcr_example, mcmcr_example, mcmcr_example)),
-               mcmcr_example, check.attributes = FALSE)
+    mcmcr_example,
+    check.attributes = FALSE
+  )
   expect_equal(combine_dimensions(bind_dimensions_n(mcmcr_example2, mcmcr_example2, mcmcr_example2)),
-               mcmcr_example2, check.attributes = FALSE)
+    mcmcr_example2,
+    check.attributes = FALSE
+  )
 })
